@@ -81,6 +81,7 @@ func main() {
 		rules.FlutterwavePublicKey(),
 		rules.FlutterwaveSecretKey(),
 		rules.FlutterwaveEncKey(),
+		rules.FlyIOAccessToken(),
 		rules.FrameIO(),
 		rules.FreshbooksAccessToken(),
 		rules.GoCardless(),
@@ -113,8 +114,7 @@ func main() {
 		rules.JWT(),
 		rules.JWTBase64(),
 		rules.KrakenAccessToken(),
-		rules.KubernetesSecretWithDataAfter(),
-		rules.KubernetesSecretWithDataBefore(),
+		rules.KubernetesSecret(),
 		rules.KucoinAccessToken(),
 		rules.KucoinSecretKey(),
 		rules.LaunchDarklyAccessToken(),
