@@ -1,6 +1,7 @@
 package rules
 
 import (
+	"github.com/zricethezav/gitleaks/v8/cmd/generate/config/utils"
 	"github.com/zricethezav/gitleaks/v8/cmd/generate/secrets"
 	"github.com/zricethezav/gitleaks/v8/config"
 )
@@ -10,7 +11,7 @@ func ConfluentSecretKey() *config.Rule {
 	r := config.Rule{
 		RuleID:      "confluent-secret-key",
 		Description: "Found a Confluent Secret Key, potentially risking unauthorized operations and data access within Confluent services.",
-		Regex:       generateSemiGenericRegex([]string{"confluent"}, alphaNumeric("64"), true),
+		Regex:       utils.GenerateSemiGenericRegex([]string{"confluent"}, utils.AlphaNumeric("64"), true),
 		Keywords: []string{
 			"confluent",
 		},
@@ -18,9 +19,9 @@ func ConfluentSecretKey() *config.Rule {
 
 	// validate
 	tps := []string{
-		generateSampleSecret("confluent", secrets.NewSecret(alphaNumeric("64"))),
+		utils.GenerateSampleSecret("confluent", secrets.NewSecret(utils.AlphaNumeric("64"))),
 	}
-	return validate(r, tps, nil)
+	return utils.Validate(r, tps, nil)
 }
 
 func ConfluentAccessToken() *config.Rule {
@@ -28,7 +29,7 @@ func ConfluentAccessToken() *config.Rule {
 	r := config.Rule{
 		RuleID:      "confluent-access-token",
 		Description: "Identified a Confluent Access Token, which could compromise access to streaming data platforms and sensitive data flow.",
-		Regex:       generateSemiGenericRegex([]string{"confluent"}, alphaNumeric("16"), true),
+		Regex:       utils.GenerateSemiGenericRegex([]string{"confluent"}, utils.AlphaNumeric("16"), true),
 
 		Keywords: []string{
 			"confluent",
@@ -37,7 +38,7 @@ func ConfluentAccessToken() *config.Rule {
 
 	// validate
 	tps := []string{
-		generateSampleSecret("confluent", secrets.NewSecret(alphaNumeric("16"))),
+		utils.GenerateSampleSecret("confluent", secrets.NewSecret(utils.AlphaNumeric("16"))),
 	}
-	return validate(r, tps, nil)
+	return utils.Validate(r, tps, nil)
 }
