@@ -1,6 +1,7 @@
 package rules
 
 import (
+	"github.com/zricethezav/gitleaks/v8/cmd/generate/config/utils"
 	"github.com/zricethezav/gitleaks/v8/cmd/generate/secrets"
 	"github.com/zricethezav/gitleaks/v8/config"
 )
@@ -10,7 +11,7 @@ func FinnhubAccessToken() *config.Rule {
 	r := config.Rule{
 		RuleID:      "finnhub-access-token",
 		Description: "Found a Finnhub Access Token, risking unauthorized access to financial market data and analytics.",
-		Regex:       generateSemiGenericRegex([]string{"finnhub"}, alphaNumeric("20"), true),
+		Regex:       utils.GenerateSemiGenericRegex([]string{"finnhub"}, utils.AlphaNumeric("20"), true),
 
 		Keywords: []string{
 			"finnhub",
@@ -19,7 +20,7 @@ func FinnhubAccessToken() *config.Rule {
 
 	// validate
 	tps := []string{
-		generateSampleSecret("finnhub", secrets.NewSecret(alphaNumeric("20"))),
+		utils.GenerateSampleSecret("finnhub", secrets.NewSecret(utils.AlphaNumeric("20"))),
 	}
-	return validate(r, tps, nil)
+	return utils.Validate(r, tps, nil)
 }
