@@ -1,6 +1,7 @@
 package rules
 
 import (
+	"github.com/zricethezav/gitleaks/v8/cmd/generate/config/utils"
 	"github.com/zricethezav/gitleaks/v8/cmd/generate/secrets"
 	"github.com/zricethezav/gitleaks/v8/config"
 )
@@ -17,7 +18,7 @@ func InfracostAPIToken() *config.Rule {
 		// Regex capture group for the actual secret
 
 		// Regex used for detecting secrets. See regex section below for more details
-		Regex: generateUniqueTokenRegex(`ico-[a-zA-Z0-9]{32}`, true),
+		Regex: utils.GenerateUniqueTokenRegex(`ico-[a-zA-Z0-9]{32}`, true),
 
 		// Keywords used for string matching on fragments (think of this as a prefilter)
 		Keywords: []string{"ico-"},
@@ -25,7 +26,7 @@ func InfracostAPIToken() *config.Rule {
 
 	// validate
 	tps := []string{
-		generateSampleSecret("ico", "ico-"+secrets.NewSecret("[A-Za-z0-9]{32}")),
+		utils.GenerateSampleSecret("ico", "ico-"+secrets.NewSecret("[A-Za-z0-9]{32}")),
 	}
-	return validate(r, tps, nil)
+	return utils.Validate(r, tps, nil)
 }
