@@ -1,6 +1,7 @@
 package rules
 
 import (
+	"github.com/zricethezav/gitleaks/v8/cmd/generate/config/utils"
 	"github.com/zricethezav/gitleaks/v8/cmd/generate/secrets"
 	"github.com/zricethezav/gitleaks/v8/config"
 )
@@ -10,8 +11,8 @@ func KrakenAccessToken() *config.Rule {
 	r := config.Rule{
 		RuleID:      "kraken-access-token",
 		Description: "Identified a Kraken Access Token, potentially compromising cryptocurrency trading accounts and financial security.",
-		Regex: generateSemiGenericRegex([]string{"kraken"},
-			alphaNumericExtendedLong("80,90"), true),
+		Regex: utils.GenerateSemiGenericRegex([]string{"kraken"},
+			utils.AlphaNumericExtendedLong("80,90"), true),
 
 		Keywords: []string{
 			"kraken",
@@ -20,8 +21,8 @@ func KrakenAccessToken() *config.Rule {
 
 	// validate
 	tps := []string{
-		generateSampleSecret("kraken",
-			secrets.NewSecret(alphaNumericExtendedLong("80,90"))),
+		utils.GenerateSampleSecret("kraken",
+			secrets.NewSecret(utils.AlphaNumericExtendedLong("80,90"))),
 	}
-	return validate(r, tps, nil)
+	return utils.Validate(r, tps, nil)
 }
